### EDDYMOTION_Correct

##### Introduction
EDDYMOTION_Correct.py helps to correct the EDDY motion artefacts in the diffusion images

##### Protocol Parameters

- estimateMoveBySusceptibility is a boolean parameter with a default value of True that indicates if the move will be estimated by susceptibility

- interpolateBadData is a boolean parameter with a default value of True that indicates if the bad data will be interpolated

- dataIsShelled is a boolean parameter with a default value of True that indicates if the data is shelled

- qcReport is a boolean parameter with a default value of False that generates a QC report from FSL

##### Examples


##### Author(s)

